SchemaSpy - gnss_data.public - Anomalies

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

SchemaSpy Analysis of gnss_data.public - Anomalies | Generated by SchemaSpy

Things that might not be 'quite right' about your schema: |

- Columns whose name and type imply a relationship to another table's primary key:
  Anomaly not detected

- Tables without indexes:

  Table | Rows
  --- | ---
  antennas | 71
  apr_coords | 0
  earthquakes | 3,263
  events | 632,745
  gamit_soln | 62,345
  keys | 7
  locks | 63
  networks | 21
  ppp_soln | 685,567
  ppp_soln_excl | 1
  receivers | 68
  rinex | 726,860
  rinex_extra | 13,308
  rinex_tank_struct | 3
  stationinfo | 998
  stations | 350

  16 instances of anomaly detected

- Columns that are flagged as both 'nullable' and 'must be unique':
  Anomaly not detected

- Tables that contain a single column:
  Anomaly not detected

- Tables with incrementing column names, potentially indicating denormalization:
  Anomaly not detected

- Columns whose default value is the word 'NULL' or 'null', but the SQL NULL value may have been intended:
  Anomaly not detected